@@ -15,7 +15,11 @@ sub array_indices {
 		[16, 32, 64, 128, 256], $default);
 
 #	unshift(@$properties, SCP_PUBLIC, MIX_IMPLICIT); # for _base version
-	my $symbols = $self->enumerated_values($prefix, [], undef, @_);
+
+	my $count = $#{$self->symbols->lookup_prefixed($prefix)};
+	my $iterator = sub { my $rv = $count; $count += 1; return($rv); };
+
+	my $symbols = $self->enumerated_values($prefix, [], $iterator, @_);
 	$self->application('constant_function', $properties, @$symbols);
 
 	return($symbols);
