@@ -9,7 +9,7 @@ sub named_values {
 	my ($self, $prefix, $default) = (shift, shift, shift);
 
 	my $properties = Package::Transporter::binary_properties(1,
-		[2, 4], $default);
+		[2, 4, 8], $default);
 
 	my @symbols = ();
 	if (scalar(@_) % 2) {
